<?php
/**
 * Nepali language file
 *
 * @author Saroj Kumar Dhakal <lotusnagarkot@gmail.com>
 * @author Saroj Kumar Dhakal <lotusnagarkot@yahoo.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'यो पृष्ठ सम्पादन गर्नुहोस् ';
$lang['btn_source']            = 'यो पृष्ठको स्रोत देखाउनुहोस् ';
$lang['btn_show']              = 'पृष्ठ देखाउनुहोस् ';
$lang['btn_create']            = 'यो पृष्ठ निर्माण गर्नुहोस्';
$lang['btn_search']            = 'खोज्नुहोस् ';
$lang['btn_save']              = 'वचत गर्नुहोस्';
$lang['btn_preview']           = 'पूर्वरुप ';
$lang['btn_top']               = 'माथि फर्कनुहोस्';
$lang['btn_newer']             = '<< यो भन्दा पछिको';
$lang['btn_older']             = 'यो भन्दा पहिलेको >>';
$lang['btn_revs']              = 'पुरानो संकरण';
$lang['btn_recent']            = 'हालैका परिवर्तनहरु ';
$lang['btn_upload']            = 'अपलोड ';
$lang['btn_cancel']            = 'रद्द गर्नुहोस् ';
$lang['btn_index']             = 'सुची';
$lang['btn_secedit']           = 'सम्पादन गर्नुहोस्';
$lang['btn_login']             = 'प्रवेश गर्नुहोस् ';
$lang['btn_logout']            = 'बाहिर जानुहोस् ';
$lang['btn_admin']             = 'एड्मिन(व्यवस्थापक)';
$lang['btn_update']            = 'अध्यावधिक गर्नुहोस्';
$lang['btn_delete']            = 'मेटाउनुहोस् ';
$lang['btn_back']              = 'पछाडि';
$lang['btn_backlink']          = 'पछाडिका लिङ्कहरु ';
$lang['btn_backtomedia']       = 'मिडिया छनौटमा फर्कनुहोस्';
$lang['btn_subscribe']         = 'पृष्ठ परिवर्तन ग्राह्य गर्नुहोस्';
$lang['btn_unsubscribe']       = 'पृष्ठ परिवर्तन अग्राह्य गर्नुहोस्';
$lang['btn_subscribens']       = 'नेमस्पेस परिवर्तन ग्राह्य गर्नुहोस् ';
$lang['btn_unsubscribens']     = 'नेमस्पेस परिवर्तन अग्राह्य गर्नुहोस् ';
$lang['btn_profile']           = 'प्रोफाइल अध्यावधिक गर्नुहोस् ';
$lang['btn_reset']             = 'पूर्वरुपमा फर्काउनुहोस';
$lang['btn_resendpwd']         = 'नयाँ प्रवेश शव्द(पासवर्ड) पठाउनुहोस् ';
$lang['btn_draft']             = ' ड्राफ्ट सम्पादन गर्नुहोस् ';
$lang['btn_recover']           = 'पहिलेको ड्राफ्ट हासिल गर्नुहोस ';
$lang['btn_draftdel']          = ' ड्राफ्ट मेटाउनुहोस् ';
$lang['btn_register']          = 'दर्ता  गर्नुहोस्';
$lang['loggedinas']            = 'प्रवेश गर्नुहोस् ';
$lang['user']                  = 'प्रयोगकर्ता ';
$lang['pass']                  = 'प्रवेशशव्द';
$lang['newpass']               = 'नयाँ प्रवेशशव्द';
$lang['oldpass']               = 'नयाँ प्रवेशशव्द निश्चित गर्नुहोस ';
$lang['passchk']               = 'एकपटक पुन:';
$lang['remember']              = 'मलाई सम्झनु';
$lang['fullname']              = 'पूरा नाम';
$lang['email']                 = 'इमेल';
$lang['profile']               = 'प्रयोगकर्ताको प्रोफाइल';
$lang['badlogin']              = 'माफ गर्नुहोस् , प्रयोगकर्तानाम वा प्रवेशशव्द गलत भयो  ';
$lang['minoredit']             = 'सामान्य परिवर्तन';
$lang['draftdate']             = 'ड्राफ्ट स्वचालित रुपमा वचत भएको';
$lang['nosecedit']             = 'यो पृष्ठ यसै बखतमा परिवर्तन भयो, खण्ड जानकारी अध्यावधिक हुन सकेन र पूरै पृष्ठ लोड भयो । ';
$lang['regmissing']            = 'माफ गर्नुहोला , सबै ठाउमा भर्नुपर्नेछ ।';
$lang['reguexists']            = 'यो नामको प्रयोगकर्ता पहिले देखि रहेको छ।';
$lang['regsuccess']            = 'यो प्रयोगकर्ता बनाइएको छ र प्रवेशशव्द इमेलमा पठइएको छ।';
$lang['regsuccess2']           = 'यो प्रयोगकर्ता बनाइएको छ ।';
$lang['regmailfail']           = 'इमेलबाट प्रवेशशब्द पठउन गल्ति भयो । कृपया एड्मिन(व्यवस्थापक)लाई सम्पर्क गर्नुहोस्  !';
$lang['regbadmail']            = 'दिएको इमेल ठेगाना गलत भए जस्तो देखिन्छ - यदि यो सहि हो भने एड्मिन(व्यवस्थापक)लाई सम्पर्क गर्नुहोस्  !';
$lang['regbadpass']            = 'दिइएका  प्रवेशशव्दहरु मिल्दैनन् , पुन: प्रयास गर्नुहोस् ।';
$lang['regpwmail']             = 'तपाईको DokuWiki प्रवेशशब्द ';
$lang['reghere']               = 'तपाईको आफ्नै खाता छैन ? अहिल्यै एउटा बनाउनुहोस् ';
$lang['profna']                = 'यो विकिले यो प्रोफाइल परिवर्तन समर्थन गर्दैन ।';
$lang['profnochange']          = 'केहि  परिवर्तन छैन , केहि गर्नु छैन ।';
$lang['profnoempty']           = 'खाली नाम वा इमेल ठेगानालाई अनुमति छैन ।';
$lang['profchanged']           = 'प्रयोगकर्ताको प्रफाइल सफलरुपमा परिवर्तन भयो ।';
$lang['pwdforget']             = 'आफ्नो पासवर्ड भुल्नु भयो ? नयाँ हासिल गर्नुहोस् ';
$lang['resendna']              = 'यो विकिबाट प्रवेशशव्द पठाउन समर्थित छैन ।';
$lang['resendpwd']             = 'नयाँ  प्रवेशशव्द पठाउनुहोस् ';
$lang['resendpwdmissing']      = 'माफ गर्नुहोस् , तपाईले सबै ठाउ भर्नुपर्छ। ';
$lang['resendpwdnouser']       = 'माफ गर्नुहोस्,  हाम्रो डेटावेसमा यो प्रयोगकर्ता भेटिएन ।';
$lang['resendpwdbadauth']      = 'माफ गर्नुहोस् , यो अनुमति चिन्ह गलत छ। तपाईले पूरै जानकारी लिङ्क प्रयोग गर्नु पर्नेछ। ';
$lang['resendpwdconfirm']      = 'तपाईको इमेलमा कन्फरमेशन लिङ्क पठाइएको छ। ';
$lang['resendpwdsuccess']      = 'तपाईको प्रवेशशव्द इमेलबाट पठाइएको छ। ';
$lang['license']               = 'खुलाइएको बाहेक, यस विकिका विषयवस्तुहरु निम्त प्रमाण द्वारा प्रमाणिक गरिएको छ।';
$lang['licenseok']             = 'नोट: यस पृष्ठ सम्पादन गरी तपाईले आफ्नो विषयवस्तु तलको प्रमाण पत्र अन्तर्गत प्रमाणिक गर्न राजी हुनु हुनेछ ।';
$lang['txt_upload']            = 'अपलोड गर्नलाई फाइल छा्न्नुहो्स्';
$lang['txt_filename']          = 'अर्को रुपमा अपलोड गर्नुहोस् (ऐच्छिक)';
$lang['txt_overwrt']           = 'रहेको उहि नामको फाइललाई मेटाउने';
$lang['lockedby']              = 'अहिले ताल्चा लगाइएको';
$lang['lockexpire']            = 'ताल्चा अवधि सकिने :';
$lang['willexpire']            = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
$lang['js']['notsavedyet']     = "तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।";
$lang['rssfailed']             = 'यो फिड लिइ आउदा गल्ति भयो ।';
$lang['nothingfound']          = 'केहि पनि भेटिएन ।';
$lang['mediaselect']           = 'मिडिया फाइलहरू ';
$lang['fileupload']            = 'मिडिया फाइल अपलोड ';
$lang['uploadsucc']            = 'अपलोड सफल ';
$lang['uploadfail']            = 'अपलोड असफल । सायद गलत अनुमति । ';
$lang['uploadwrong']           = 'अपलोड असमर्थित । फाइल एक्सटेन्सन अमान्य।  ';
$lang['uploadexist']           = 'फाइल पहिलेदेखि छ। केहि गरिएन ।';
$lang['uploadbadcontent']      = 'अपलोड गरिएको वस्तु %s फाइल एक्टेन्सन अनुसार मिलेन ।';
$lang['uploadspam']            = 'अपलोड स्प्याम कालो सुचीले रोकिएको छ। ';
$lang['uploadxss']             = 'अपलोड सम्भवत: हानिकारक वस्तुको कारणले रोकिएको। ';
$lang['deletesucc']            = 'फाइल  "%s"  मेटिएको छ। ';
$lang['deletefail']            = '"%s"  मेट्न सकिएन - अनुमति हेर्नुहोस् ।';
$lang['mediainuse']            = 'फाइल "%s" मेटिएको छैन - प्रयोगमा छ।';
$lang['namespaces']            = 'नेमस्पेसहरु ';
$lang['mediafiles']            = ' उपलब्ध फाइलहरु ';
$lang['js']['keepopen']        = 'छनौटमा विन्डो खुला राख्नुहोस् ';
$lang['js']['hidedetails']     = 'जानकारी लुकाउनु होस् ';
$lang['js']['nosmblinks']      = 'विन्डोहरु लिङ्क गर्दा माइक्रो सफ्ट एक्सप्लोररमामात्र  काम साझा हुन्छ । तर कपि गर्न र टास्न मिल्छ।   ';
$lang['js']['mu_btn']          = 'धेरै वटा फाइलहरु एकैपटक अपलोड गर्नुहोस् ।';
$lang['mediausage']            = 'फाइललाई रेफरेन्स गर्न निम्न सुत्र प्रयोग गर्नुहोस् :';
$lang['mediaview']             = 'सक्कली फाइल हेर्नुहोस् ';
$lang['mediaroot']             = 'रुट(मूख्य प्रयोगकर्ता)';
$lang['mediaupload']           = 'अहिलेको नेमस्पेसमा यहा अपलोड गर्नुहोस् । सबनेमस्पेसहरु बनाउन "रुपमा आपलोड" छानी फाइलहरुलाई कोलोन(:) ले छुट्टयाउनुहोस् ।';
$lang['mediaextchange']        = 'फाइल एकस्टेन्सन .%s देखि  .%s मा परिवरतित भयो ';
$lang['reference']             = 'रेफररेन्स ';
$lang['ref_inuse']             = 'फाइल मेट्न मिलेन , किनभने यो निम्न पृष्ठहरुद्वारा प्रयोगमा छ। ';
$lang['ref_hidden']            = 'केहि रेफरेन्स यस्ता पृष्ठहरुमा छन् जुन हेर्न तपाईलाई अनुमति छैन ।';
$lang['hits']                  = 'मिलेको';
$lang['quickhits']             = 'मिलेका पृष्ठनामहरु ';
$lang['toc']                   = 'वस्तुहरुको सुची';
$lang['current']               = 'हालको';
$lang['yours']                 = 'तपाईको संस्करण';
$lang['diff']                  = 'हालको संस्करण सँगको भिन्नता';
$lang['diff2']                 = 'रोजिएका संस्करण वीचका भिन्नताहरु ';
$lang['line']                  = 'हरफ';
$lang['breadcrumb']            = 'छुट्ट्याउनुहोस् ';
$lang['youarehere']            = 'तपाई यहा हुनुहुन्छ';
$lang['lastmod']               = 'अन्तिम पटक सच्याइएको';
$lang['by']                    = 'द्वारा ';
$lang['deleted']               = 'हटाइएको';
$lang['created']               = 'निर्माण गरिएको';
$lang['restored']              = 'पुरानो संस्करण पुनर्‌प्रयोग गरिएको';
$lang['external_edit']         = 'बाह्य सम्पादन';
$lang['summary']               = 'सम्पादनको बारेमा';
$lang['mail_newpage']          = 'थपिएको पृष्ठ';
$lang['mail_changed']          = 'परिवर्तित पृष्ठ';
$lang['mail_new_user']         = 'नयाँ प्रयोगकर्ता ';
$lang['mail_upload']           = 'अपलोड गरिएको फाइल';
$lang['qb_bold']               = 'मोटो पाठ(बोल्ड)';
$lang['qb_italic']             = 'इटालिक पाठ';
$lang['qb_underl']             = 'निम्न रेखांकित(अन्डरलाइन) पाठ';
$lang['qb_code']               = 'चिन्ह(कोड) पाठ';
$lang['qb_strike']             = 'स्ट्राइकथ्रु पाठ';
$lang['qb_h1']                 = 'पहिलो स्तरको शिर्षक(लेभल १ हेडलाइन)';
$lang['qb_h2']                 = 'दोस्रो स्तरको  शिर्षक(लेभल २ हेडलाइन)';
$lang['qb_h3']                 = 'तेस्रो स्तरको  शिर्षक(लेभल ३ हेडलाइन)';
$lang['qb_h4']                 = 'चौथो स्तरको  शिर्षक(लेभल ४ हेडलाइन)';
$lang['qb_h5']                 = 'पाचौँ स्तरको  शिर्षक(लेभल ५ हेडलाइन)';
$lang['qb_link']               = 'आन्तरिक लिङ्क ';
$lang['qb_extlink']            = 'वाह्य लिङ्क';
$lang['qb_hr']                 = 'क्षितिज (होरिजोन्टल) रुल';
$lang['qb_ol']                 = 'मिलाइएको सुची';
$lang['qb_ul']                 = 'नमिलाइएको सुची';
$lang['qb_media']              = 'तस्विर र अरु फाइलहरु थप्नुहोस्';
$lang['qb_sig']                = 'हस्ताक्षर थप्नुहोस् ';
$lang['qb_smileys']            = 'स्माइलीहरु ';
$lang['qb_chars']              = 'विशेष वर्णहरु ';
$lang['js']['del_confirm']           = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
$lang['admin_register']        = 'नयाँ प्रयोगकर्ता थप्नुहोस् ';
$lang['metaedit']              = 'मेटाडेटा सम्पादन गर्नुहोस्';
$lang['metasaveerr']           = 'मेटाडाटा लेखन असफल';
$lang['metasaveok']            = 'मेटाडाटा वचत भयो ';
$lang['img_backto']            = 'फिर्ता';
$lang['img_title']             = 'शिर्षक';
$lang['img_caption']           = 'निम्न लेख';
$lang['img_date']              = 'मिति';
$lang['img_fname']             = 'फाइलनाम';
$lang['img_fsize']             = 'आकार';
$lang['img_artist']            = 'चित्रकार';
$lang['img_copyr']             = 'सर्वाधिकार';
$lang['img_format']            = 'ढाचा';
$lang['img_camera']            = 'क्यामेरा';
$lang['img_keywords']          = 'खोज शब्द';
$lang['subscribe_success']     = '%s ,%s को ग्राह्यताको लागि थपियो  ';
$lang['subscribe_error']       = '%s ,%s को ग्राह्यताको लागि थपिदा त्रुटि';
$lang['subscribe_noaddress']   = 'तपाईको खातासँग कुनै पनि ठेगाना संबन्धित छैन , तपाईलाई  ग्रहाक सुचीमा राखन मिलेन।';
$lang['unsubscribe_success']   = '%s लाई %s को ग्रहाक सुचीबाट हटाइयो';
$lang['unsubscribe_error']     = '%s लाई %s को ग्राहक सुचीबाट हटाउदा त्रुटि';
$lang['authmodfailed']         = 'खराब प्रयोगकर्ता प्रामाणिकरण विधि ।तपाईको विकी एड्मिनलाई खवर गर्नुहोस् ।';
$lang['authtempfail']          = 'प्रयोगकर्ता प्रामाणिकरण अस्थाइरुपमा अनुपलब्ध छ। यदि यो समस्या रहि रहेमा तपाईको  विकि एड्मिनलाई खवर गर्नुहोला ।';
$lang['i_chooselang']          = 'भाषा छान्नुहोस् ';
$lang['i_installer']           = 'DokuWiki  स्थापक';
$lang['i_wikiname']            = 'विकी नाम';
$lang['i_enableacl']           = 'ACL लागु गर्नुहोस्( सिफारिस गरिएको)';
$lang['i_superuser']           = 'मूख्य प्रयोगकर्ता';
$lang['i_problems']            = 'स्थापकले तल देखाइएको त्रुटि फेला पार्‌यो ।तपाईले  यो त्रुटि नसच्याए सम्म अगि बढ्न सक्नुहुने छैन।';
$lang['i_modified']            = 'सुरक्षाको कारणले यो स्क्रिप्ट नया तथा नसच्याइएको Dokuwiki स्थापनामा  मात्र काम गर्छ।  तपाईले कि डाउनलोड गर्नुभएको प्याकेज पुन: खोल्नुहोस्  कि <a href="http://dokuwiki.org/install">Dokuwiki स्थापना विधि</a>';
$lang['i_funcna']              = 'PHP function <code>%s</code> उपलव्ध छैन । हुनसक्छ तपाईको होस्टिङ्ग प्रदायकले कुनै कारण वश यसलाई वन्द गरिदिएका हुनसक्छन् । ';
$lang['i_phpver']              = 'तपाईको PHP संस्करण <code>%s</code> चाहिएको <code>%s</code> भन्दा कम छ। तपाईले आफ्नो PHP स्थापना अध्यावधिक गर्नुपर्छ ।';
$lang['i_permfail']            = '<code>%s</code> DokuWiki द्वारा लेख्य छैन । तपाईले डाइरेक्टरीको अनुमति परिवर्तन गर्नुपर्छ !';
$lang['i_confexists']          = '<code>%s</code> पहिले देखि नै रहेको छ।';
$lang['i_writeerr']            = '<code>%s</code> बनाउन असमर्थ । तपाईले डाइरेक्टरी / फाइल अनुमति जाच्नु पर्छ र फाइल आफैले बनाउनु पर्छ ।';
$lang['i_badhash']             = 'पहिचान हुन नसकेको वा परिवर्तित  okuwiki.php (hash=code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - अवैध वा रित्तो मान ';
$lang['i_success']             = 'स्थापना सफलरुपमा समाप्त भयो ।तपाई install.php मेट्न सक्नुहु्न्छ । <a href="doku.php">तपाईको नयाँ DokuWiki</a> निरन्तर गर्न सक्नुहुन्छ ।';
$lang['i_failure']             = 'स्थापना समयमा केहि त्रुटि फेला पर्यो ।तपाईले आफैले यसलाई <a href="doku.php">तपाईको नयाँ DokuWiki</a> प्रयोग गर्नु अगि	सच्याउनुपर्ने  हुन्छ ।';
$lang['i_policy']              = 'सुरुको ACL निति';
$lang['i_pol0']                = 'खुल्ला विकि (पठन, लेखन , अपलोड ) सबैका लागि';
$lang['i_pol1']                = 'Public विकि (पठन सवैका लागि,लेखन र अपलोड दर्ता गरिएका प्रयपगकर्ताका लागि ) ';
$lang['i_pol2']                = 'बन्द विकि (पठन , लेखन, अपलोड ) दर्ता भएका प्रयोगकर्ताका लागि मात्र ।';
$lang['i_retry']               = 'पुन: प्रयास गर्नुहोस् ';
$lang['mu_intro']              = 'तपाईले धेरै वटा फाइलहरु एकै पटक अपलोड गर्न सक्नुहुन्छ । browse थिच्नुहोस् अनि सुचीमा थप्नुहोस् । सकिएपछि अपलोड थिछ्चुहोस् ।';
$lang['mu_gridname']           = 'फाइलनाम ';
$lang['mu_gridsize']           = 'आकार';
$lang['mu_gridstat']           = 'स्थिति';
$lang['mu_namespace']          = 'नेमस्पेस';
$lang['mu_browse']             = 'Browse';
$lang['mu_toobig']             = 'धेरै ठूलो';
$lang['mu_ready']              = 'अपलोडको लागि तयार';
$lang['mu_done']               = 'पूरा';
$lang['mu_fail']               = 'असफल';
$lang['mu_authfail']           = 'सत्र सकियो ';
$lang['mu_progress']           = '@PCT@% अपलोड भयो ';
$lang['mu_filetypes']          = 'समर्थित फाइल प्रकार';
$lang['recent_global']         = 'तपाई अहिले <b>%s</b> नेमस्पेस भित्र भएका परिवर्तन हेर्दैहुनुहुन्छ। तपाई <a href="%s">पुरै विकिमा भएको परिवर्तन हेर्न सक्नुहुन्छ</a>.';
